@@ -1,5 +1,7 @@
-### from pamr package
- balanced.folds <- function(y, nfolds = min(min(table(y)), 10)) {
+### Obtained from the now orphaned R package pamr version 1.56.2
+### Author: T. Hastie, R. Tibshirani, Balasubramanian Narasimhan, Gil Chu
+
+balanced.folds <- function(y, nfolds = min(min(table(y)), 10)) {
    totals <- table(y)
    fmax <- max(totals)
    nfolds <- min(nfolds, fmax)     
@@ -11,7 +13,7 @@
 ###Make a big matrix, with enough rows to get in all the folds per class
    bigmat <- matrix(NA, ceiling(fmax/nfolds) * nfolds, length(totals))
    for(i in seq(totals)) {
-#cat(i)
+cat(i)
      if(length(yids[[i]])>1){bigmat[seq(totals[i]), i] <- sample(yids[[i]])}
      if(length(yids[[i]])==1){bigmat[seq(totals[i]), i] <- yids[[i]]}
 
