@@ -3,7 +3,7 @@ loss2 <- function(y, f, weights, cfun, dfun, s, delta=0.0001){
     dfun <- dfun2num(dfun)
     #if(!dfun %in% c(1, 4:7)) stop("dfun is not implemented")
     if(!cfun %in% 1:8) stop("cfun is not implemented")
-    check_s(cfun, s)
+    check_s(cfun, dfun, s)
     if(dfun %in% 4:7 && !setequal(unique(y), c(-1, 1))) stop("y must be -1/1 for binary classification")
     n <- length(y)
     if(n!=length(f)) stop("y and f should have comparable length\n")
@@ -29,7 +29,7 @@ loss2 <- function(y, f, weights, cfun, dfun, s, delta=0.0001){
 }
 
 loss2_irsvm <- function(y, f, weights, cfun, dfun, s, eps, delta=0.0001){
-    check_s(cfun, s)
+    check_s(cfun, dfun=6, s)
     cfun <- cfun2num(cfun)
     if(!cfun %in% 1:8) stop("cfun is not implemented")
     dfun <- switch(dfun,
